ClientConfig

Trait ClientConfig 

pub trait ClientConfig: Debug {
    // Required method
    fn as_any(&self) -> &dyn Any;
}
Configuration for creating client instances.

This trait allows different client types to provide their configuration in a type-safe manner while still being usable in generic factory contexts.

Required Methods

fn as_any(&self) -> &dyn Any

Return the configuration as a trait object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors